// reference: https://d3-graph-gallery.com/graph/bubble_template.html 

// set the dimensions and margins of the graph
const margin = { top: 150, right: 350, bottom: 75, left: 75 },
  width = 900 - margin.left - margin.right,
  height = 700 - margin.top - margin.bottom;

//append the svg object to the body of the page
const svg = d3
  .select("#my_dataviz")
  .append("svg")
  .attr("width", width + margin.left + margin.right)
  .attr("height", height + margin.top + margin.bottom)
  .append("g")
  .attr("transform", `translate(${margin.left},${margin.top})`);

//Graph Title 
svg.append("text")
    .attr("x", width / 2)
		.attr("y",-80)
    .attr("text-anchor", "middle")
    .text("Chips Ratings Vs Sodium Levels In USA")
		.style("font-size", "35px") ;

// Read the csv data
d3.csv("data.csv").then((data) => {
  
  // add x axis
  const x = d3.scaleLinear()
  .domain([0, 100])
  .range([0,width]);
  
  //visualize x axis
  svg.append("g")
    .attr("transform", `translate(0, ${height})`)
    .call(d3.axisBottom(x));

  // Adding x axis label
  svg.append("text")
  	.attr("class","x label")
    .attr("text-anchor", "middle")
    .attr("x", width/2)
    .attr("y", height + 50)
  	.style("font-size", "20px")
    .text("Chips Rating");

  // Adding y axis
	const y = d3.scaleLinear()
		.domain([0, 350])
		.range([height, 0])
	
  //visualize the y axis
	svg.append("g")
		.call(d3.axisLeft(y));

  // Add y axis label:
  svg.append("text")
    .attr("text-anchor", "middle")
    .attr("x", -height / 2)
    .attr("y", -50)
    .text("Sodium Levels")
  	.style("font-size", "20px")
    .attr("transform", "rotate(-90)");

  //Add a scale for bubble size
  const z = d3.scaleLinear()
  	.domain([0,150]) //max 
  	.range([0, 23]);
  

   // add a scale for bubble color
  const myColor = d3.scaleOrdinal()
  .domain(["T","S","M","L","P","D","R"])
  .range(d3.schemeSet1);

  // Add Bubbles
  svg.append("g")
    .selectAll("dot")
    .data(data)
    .join("circle")
    .attr("class", "bubbles")
    .attr("cx", (d) => x(d.rating))
    .attr("cy", (d) => y(d.sodium))
    .attr("r", (d) => z(d.calories))
    .style("fill", (d) => myColor(d.chips))
  	.style("opacity", "0.7")
    .attr("stroke", "black");
 
  //Bubble size legend
   const valuesToShow = [50, 100,150];
  
  //circle sizes
  	svg.selectAll("legend")
  	.data(valuesToShow)
  	.join("circle")
  	.attr("cx",(d) => z(d)*6+640 )
  	.attr("cy", (d) => height - 150 - z(d))
  	.attr("r", (d) => z(d))
  	.style("fill", "crimson")
  	.style("opacity", "0.7")
  	.attr("stroke", "black");

 //Size number labels 
  svg.append("text")
    .attr("x", 685)
  	.attr("y",355)
    .text("50")
  	.style("font-size", 15)
    .attr("text-anchor", "middle");
  
   svg.append("text")
    .attr("x", 735)
  	.attr("y",355)
    .text("100")
  	.style("font-size", 15)
    .attr("text-anchor", "middle");
  
    svg.append("text")
    .attr("x", 785)
  	.attr("y",355)
    .text("150")
  	.style("font-size", 15)
    .attr("text-anchor", "middle");

  // Size legend title
  svg.append("text")
    .attr("x", 740)
  	.attr("y",400)
    .text("Calorie Size")
  	.style("font-size", 20)
    .attr("text-anchor", "middle");

//Bubble color legend
  const size = 20;
  const newgroups=["Takis", "Simply7Snacks", "MissVickies", "Lays","Pringles", "Doritos", "Ruffles"];
  const myLabelColor = d3.scaleOrdinal()
  .domain(["Takis", "Simply7Snacks", "MissVickies", "Lays","Pringles", "Doritos", "Ruffles"])
  .range(d3.schemeSet1);
 
  //add colored dots for legend
  svg.selectAll("myrect")
    .data(newgroups)
    .join("circle")
    .attr("cx", 650)
    .attr("cy", (d, i) => 10 + i * (size + 7))
    .attr("r", 5)
    .style("fill", (d) => myLabelColor(d))
  	.style("opacity", "0.7")
  	.attr("stroke", "black");

  // add labels beside colored dots 
  svg.selectAll("mylabels")
    .data(newgroups)
    .enter()
    .append("text")
  	.attr("x", 680)
    .attr("y", (d, i) => 10 + i * (size + 7))
    .style("fill", (d) => myLabelColor(d))
    .text((d) => d)
    .attr("text-anchor", "left")
    .style("alignment-baseline", "middle");
 
  //color legend title 
   svg.append("text")
    .attr("x", 690)
  	.attr("y",-20)
    .text("Chips:")
  	.style("font-size", 18)
    .attr("text-anchor", "middle");

});

